@@ -12,16 +12,18 @@ pub struct Submission {
     pub id: String,
     pub author: String,
     pub score: f64,
-    pub num_comments: u64,
+    pub num_comments: i64,
     pub thumbnail: String,
     pub subreddit_id: String,
     pub downs: f64,
     pub ups: f64,
     pub stickied: bool,
     pub locked: bool,
+    pub over_18: bool,
     pub name: String,
     pub created: f64,
     pub url: Option<String>,
+    pub permalink: String,
     pub title: String,
     pub created_utc: f64,
     pub distinguished: Option<String>,
